@@ -4,7 +4,9 @@ use 5.006;
 use warnings;
 use strict;
 
-our $VERSION = '1.02_02';
+our $VERSION = '1.04_01';
+
+=for stopwords inline
 
 =head1 NAME
 
@@ -30,7 +32,7 @@ This class is used to identify all image nodes in a page content tree.
 
 =over
 
-=item new
+=item $self->new()
 
 Creates a new renderer.
 
@@ -39,12 +41,15 @@ Creates a new renderer.
 sub new
 {
    my $pkg = shift;
-   return bless {}, $pkg;
+   return bless {
+      images => [],
+   }, $pkg;
 }
 
-=item clone
+=item $self->clone()
 
-Duplicates an instance.
+Duplicates an instance.  The new instance deliberately shares its
+C<images> property with the original instance.
 
 =cut
 
@@ -55,9 +60,10 @@ sub clone
    my $pkg = ref $obj;
    my $self = $pkg->new();
    $self->{images} = $obj->{images};
+   return $self;
 }
 
-=item Do DATA...
+=item $self->Do(DATA...)
 
 Record an indirect image node.
 
@@ -68,14 +74,14 @@ sub Do
    my $self = shift;
    my $value = [@_];
 
-   $self->{images} ||= [];
    push @{$self->{images}}, {
       type => 'Do',
       value => $value,
    };
+   return;
 }
 
-=item BI DATA...
+=item $self->BI(DATA...)
 
 Record an inline image node.
 
@@ -86,11 +92,11 @@ sub BI
    my $self = shift;
    my $value = [@_];
 
-   $self->{images} ||= [];
    push @{$self->{images}}, {
       type => 'BI',
       value => $value,
    };
+   return;
 }
 
 1;
@@ -101,3 +107,5 @@ __END__
 =head1 AUTHOR
 
 Clotho Advanced Media Inc., I<cpan@clotho.com>
+
+=cut
