@@ -1,10 +1,15 @@
 #!/usr/bin/perl -w
 
+package main;
+
+use warnings;
 use strict;
 use CAM::PDF;
 use Getopt::Long;
 use Pod::Usage;
 
+our $VERSION = '1.04_01';
+
 my %opts = (
             verbose    => 0,
             order      => 0,
@@ -12,14 +17,21 @@ my %opts = (
             version    => 0,
             );
 
-Getopt::Long::Configure("bundling");
-GetOptions("v|verbose"  => \$opts{verbose},
-           "o|order"    => \$opts{order},
-           "h|help"     => \$opts{help},
-           "V|version"  => \$opts{version},
+Getopt::Long::Configure('bundling');
+GetOptions('v|verbose'  => \$opts{verbose},
+           'o|order'    => \$opts{order},
+           'h|help'     => \$opts{help},
+           'V|version'  => \$opts{version},
            ) or pod2usage(1);
-pod2usage(-exitstatus => 0, -verbose => 2) if ($opts{help});
-print("CAM::PDF v$CAM::PDF::VERSION\n"),exit(0) if ($opts{version});
+if ($opts{help})
+{
+   pod2usage(-exitstatus => 0, -verbose => 2);
+}
+if ($opts{version})
+{
+   print "CAM::PDF v$CAM::PDF::VERSION\n";
+   exit 0;
+}
 
 if (@ARGV < 3)
 {
@@ -29,27 +41,29 @@ if (@ARGV < 3)
 my $infile = shift;
 my $fromstr = shift;
 my $tostr = shift;
-my $outfile = shift || "-";
+my $outfile = shift || q{-};
 
-my $doc = CAM::PDF->new($infile);
-die "$CAM::PDF::errstr\n" if (!$doc);
+my $doc = CAM::PDF->new($infile) || die "$CAM::PDF::errstr\n";
 
 foreach my $p (1 .. $doc->numPages())
 {
    my $content = $doc->getPageContent($p);
-   if ($content =~ s/$fromstr/$tostr/g)
+   if ($content =~ s/$fromstr/$tostr/gxms)
    {
       $doc->setPageContent($p, $content);
    }
 }
 
-if ((!scalar (%{$doc->{changes}})) && exists $doc->{contents})
+if (!scalar %{$doc->{changes}} && exists $doc->{contents})
 {
    $doc->output($outfile);
 }
 else
 {
-   $doc->preserveOrder() if ($opts{order});
+   if ($opts{order})
+   {
+      $doc->preserveOrder();
+   }
    if (!$doc->canModify())
    {
       die "This PDF forbids modification\n";
@@ -59,13 +73,15 @@ else
 
 __END__
 
+=for stopwords changepagestring.pl
+
 =head1 NAME
 
 changepagestring.pl - Search and replace in all PDF pages
 
 =head1 SYNOPSIS
 
-changepagestring.pl [options] infile.pdf search-regex replace-str [outfile.pdf]
+ changepagestring.pl [options] infile.pdf search-regex replace-str [outfile.pdf]
 
  Options:
    -o --order          preserve the internal PDF ordering for output
@@ -75,18 +91,20 @@ changepagestring.pl [options] infile.pdf search-regex replace-str [outfile.pdf]
 
 =head1 DESCRIPTION
 
-Searches through all pages of a PDF file for instances of search-regex
-and inserts replace-str.  The regex should be a form that Perl
+Searches through all pages of a PDF file for instances of C<search-regex>
+and inserts C<replace-str>.  The regex should be a form that Perl
 understands.  Note that this does not change the PDF metadata like
 forms and annotation.  To change metadata, use instead
-changepdfstring.pl.
+F<changepdfstring.pl>.
 
 =head1 SEE ALSO
 
 CAM::PDF
 
-changepdfstring.pl
+F<changepdfstring.pl>
 
 =head1 AUTHOR
 
 Clotho Advanced Media Inc., I<cpan@clotho.com>
+
+=cut
