@@ -1,10 +1,15 @@
 #!/usr/bin/perl -w
 
+package main;
+
+use warnings;
 use strict;
 use CAM::PDF;
 use Getopt::Long;
 use Pod::Usage;
 
+our $VERSION = '1.04_01';
+
 my %opts = (
             verbose    => 0,
             order      => 0,
@@ -12,14 +17,21 @@ my %opts = (
             version    => 0,
             );
 
-Getopt::Long::Configure("bundling");
-GetOptions("v|verbose"  => \$opts{verbose},
-           "o|order"    => \$opts{order},
-           "h|help"     => \$opts{help},
-           "V|version"  => \$opts{version},
+Getopt::Long::Configure('bundling');
+GetOptions('v|verbose'  => \$opts{verbose},
+           'o|order'    => \$opts{order},
+           'h|help'     => \$opts{help},
+           'V|version'  => \$opts{version},
            ) or pod2usage(1);
-pod2usage(-exitstatus => 0, -verbose => 2) if ($opts{help});
-print("CAM::PDF v$CAM::PDF::VERSION\n"),exit(0) if ($opts{version});
+if ($opts{help})
+{
+   pod2usage(-exitstatus => 0, -verbose => 2);
+}
+if ($opts{version})
+{
+   print "CAM::PDF v$CAM::PDF::VERSION\n";
+   exit 0;
+}
 
 if (@ARGV < 3)
 {
@@ -29,10 +41,9 @@ if (@ARGV < 3)
 my $infile = shift;
 my $fromstr = shift;
 my $tostr = shift;
-my $outfile = shift || "-";
+my $outfile = shift || q{-};
 
-my $doc = CAM::PDF->new($infile);
-die "$CAM::PDF::errstr\n" if (!$doc);
+my $doc = CAM::PDF->new($infile) || die "$CAM::PDF::errstr\n";
 
 foreach my $objnum (keys %{$doc->{xref}})
 {
@@ -40,13 +51,16 @@ foreach my $objnum (keys %{$doc->{xref}})
    $doc->changeString($obj, {$fromstr => $tostr});
 }
 
-if ((!scalar (%{$doc->{changes}})) && exists $doc->{contents})
+if (!scalar %{$doc->{changes}} && exists $doc->{contents})
 {
    print $doc->{contents};
 }
 else
 {
-   $doc->preserveOrder() if ($opts{order});
+   if ($opts{order})
+   {
+      $doc->preserveOrder();
+   }
    if (!$doc->canModify())
    {
       die "This PDF forbids modification\n";
@@ -56,13 +70,15 @@ else
 
 __END__
 
+=for stopwords changepdfstring.pl
+
 =head1 NAME
 
 changepdfstring.pl - Search and replace in PDF metadata
 
 =head1 SYNOPSIS
 
-changepdfstring.pl [options] infile.pdf search-str replace-str [outfile.pdf]
+ changepdfstring.pl [options] infile.pdf search-str replace-str [outfile.pdf]
 
  Options:
    -o --order          preserve the internal PDF ordering for output
@@ -72,12 +88,12 @@ changepdfstring.pl [options] infile.pdf search-str replace-str [outfile.pdf]
 
 =head1 DESCRIPTION
 
-Searches through a PDF file's metadata for instances of search-str and
-inserts replace-str.  Note that this does not change the actual PDF
+Searches through a PDF file's metadata for instances of C<search-str> and
+inserts C<replace-str>.  Note that this does not change the actual PDF
 page layout, but only interactive features, like forms and annotation.
-To change page layout strings, use instead changepagestring.pl.
+To change page layout strings, use instead F<changepagestring.pl>.
 
-The search-str can be a literal string, or it can be a Perl regular
+The C<search-str> can be a literal string, or it can be a Perl regular
 expression by wrapping it in C<regex(...)>.  For example:
 
   changepdfstring.pl in.pdf 'regex(CAM-PDF-(\d.\d+))' 'version=$1' out.pdf
@@ -86,9 +102,10 @@ expression by wrapping it in C<regex(...)>.  For example:
 
 CAM::PDF
 
-changepagestring.pl
+F<changepagestring.pl>
 
 =head1 AUTHOR
 
 Clotho Advanced Media Inc., I<cpan@clotho.com>
 
+=cut
