@@ -1,10 +1,15 @@
 #!/usr/bin/perl -w
 
+package main;
+
+use warnings;
 use strict;
 use CAM::PDF;
 use Getopt::Long;
 use Pod::Usage;
 
+our $VERSION = '1.04_01';
+
 my %opts = (
             verbose    => 0,
             order      => 0,
@@ -12,14 +17,21 @@ my %opts = (
             version    => 0,
             );
 
-Getopt::Long::Configure("bundling");
-GetOptions("v|verbose"  => \$opts{verbose},
-           "o|order"    => \$opts{order},
-           "h|help"     => \$opts{help},
-           "V|version"  => \$opts{version},
+Getopt::Long::Configure('bundling');
+GetOptions('v|verbose'  => \$opts{verbose},
+           'o|order'    => \$opts{order},
+           'h|help'     => \$opts{help},
+           'V|version'  => \$opts{version},
            ) or pod2usage(1);
-pod2usage(-exitstatus => 0, -verbose => 2) if ($opts{help});
-print("CAM::PDF v$CAM::PDF::VERSION\n"),exit(0) if ($opts{version});
+if ($opts{help})
+{
+   pod2usage(-exitstatus => 0, -verbose => 2);
+}
+if ($opts{version})
+{
+   print "CAM::PDF v$CAM::PDF::VERSION\n";
+   exit 0;
+}
 
 if (@ARGV < 2)
 {
@@ -28,16 +40,18 @@ if (@ARGV < 2)
 
 my $infile = shift;
 my $pagenums = shift;
-my $outfile = shift || "-";
+my $outfile = shift || q{-};
 
-my $doc = CAM::PDF->new($infile);
-die "$CAM::PDF::errstr\n" if (!$doc);
+my $doc = CAM::PDF->new($infile) || die "$CAM::PDF::errstr\n";
 
 if (!$doc->deletePages($pagenums))
 {
    die "Failed to delete a page\n";
 }
-$doc->preserveOrder() if ($opts{order});
+if ($opts{order})
+{
+   $doc->preserveOrder();
+}
 if (!$doc->canModify())
 {
    die "This PDF forbids modification\n";
@@ -47,13 +61,15 @@ $doc->cleanoutput($outfile);
 
 __END__
 
+=for stopwords deletepdfpage.pl
+
 =head1 NAME
 
 deletepdfpage.pl - Remove one or more pages from a PDF
 
 =head1 SYNOPSIS
 
-deletepdfpage.pl [options] infile.pdf <pagenums> [outfile.pdf]
+ deletepdfpage.pl [options] infile.pdf <pagenums> [outfile.pdf]
 
  Options:
    -o --order          preserve the internal PDF ordering for output
@@ -75,8 +91,10 @@ Illustrator emits.
 
 CAM::PDF
 
-appendpdf.pl
+C<appendpdf.pl>
 
 =head1 AUTHOR
 
 Clotho Advanced Media Inc., I<cpan@clotho.com>
+
+=cut
