@@ -1,11 +1,15 @@
 #!/usr/bin/perl -w
 
+package main;
+
 use warnings;
 use strict;
 use CAM::PDF;
 use Getopt::Long;
 use Pod::Usage;
 
+our $VERSION = '1.04_01';
+
 my %opts = (
             template   => 'crunchjpg_tmpl.pdf',
 
@@ -41,7 +45,7 @@ foreach my $flag (qw( skip only ))
 {
    foreach my $val (@{$opts{$flag.'val'}})
    {
-      foreach my $key (split /\D+/, $val)
+      foreach my $key (split /\D+/xms, $val)
       {
          $opts{$flag}->{$key} = 1;
       }
@@ -154,8 +158,8 @@ foreach my $objnum (keys %{$doc->{xref}})
          $media_array->[2]->{value} = $w;
          $media_array->[3]->{value} = $h;
          my $page = $rawpage;
-         $page =~ s/xxx/$w/ig;
-         $page =~ s/yyy/$h/ig;
+         $page =~ s/xxx/$w/igxms;
+         $page =~ s/yyy/$h/igxms;
          $tmpl->setPageContent(1, $page);
          $tmpl->replaceObject(9, $doc, $objnum, 1);
          
@@ -196,17 +200,21 @@ sub _inform
    {
       print STDERR $str, "\n";
    }
+   return;
 }
 
 __END__
 
+
+=for stopwords extractallimages.pl ImageMagick
+
 =head1 NAME
 
 extractallimages.pl - Save copies of all PDF images to a directory
 
 =head1 SYNOPSIS
 
-extractallimages.pl [options] infile.pdf outdirectory
+ extractallimages.pl [options] infile.pdf outdirectory
 
  Options:
    -O --only=imnum     only output the specified images (can be used mutliple times)
@@ -216,28 +224,30 @@ extractallimages.pl [options] infile.pdf outdirectory
    -V --version        print CAM::PDF version
 
 C<imnum> is a comma-separated list of integers indicating the images
-in order that they appear in the PDF.  Use listimages.pl to retrieve
+in order that they appear in the PDF.  Use F<listimages.pl> to retrieve
 the image numbers.
 
 =head1 DESCRIPTION
 
-Requires the ImageMagick C<convert> program to be available
+Requires the ImageMagick B<convert> program to be available
 
 Searches the PDF for images and saves them as individual files in the
-specified directory.  The files are named <imnum>.jpg or <imnum>.gif.
+specified directory.  The files are named C<E<lt>imnumE<gt>.jpg> or C<E<lt>imnumE<gt>.gif>.
 
 =head1 SEE ALSO
 
 CAM::PDF
 
-crunchjpgs.pl
+F<crunchjpgs.pl>
 
-listimages.pl
+F<listimages.pl>
 
-extractjpgs.pl
+F<extractjpgs.pl>
 
-uninlinepdfimages.pl
+F<uninlinepdfimages.pl>
 
 =head1 AUTHOR
 
 Clotho Advanced Media Inc., I<cpan@clotho.com>
+
+=cut
