@@ -1,12 +1,17 @@
 #!/usr/bin/perl -w
 
+package main;
+
+use warnings;
 use strict;
 use CAM::PDF;
 use Getopt::Long;
 use Pod::Usage;
 
+our $VERSION = '1.04_01';
+
 my %opts = (
-            template   => "crunchjpg_tmpl.pdf",
+            template   => 'crunchjpg_tmpl.pdf',
 
             verbose    => 0,
             help       => 0,
@@ -17,20 +22,27 @@ my %opts = (
             skipval    => [],
             );
 
-Getopt::Long::Configure("bundling");
-GetOptions("S|skip=s"     => \@{$opts{skipval}},
-           "v|verbose"  => \$opts{verbose},
-           "h|help"     => \$opts{help},
-           "V|version"  => \$opts{version},
+Getopt::Long::Configure('bundling');
+GetOptions('S|skip=s'     => \@{$opts{skipval}},
+           'v|verbose'  => \$opts{verbose},
+           'h|help'     => \$opts{help},
+           'V|version'  => \$opts{version},
            ) or pod2usage(1);
-pod2usage(-exitstatus => 0, -verbose => 2) if ($opts{help});
-print("CAM::PDF v$CAM::PDF::VERSION\n"),exit(0) if ($opts{version});
+if ($opts{help})
+{
+   pod2usage(-exitstatus => 0, -verbose => 2);
+}
+if ($opts{version})
+{
+   print "CAM::PDF v$CAM::PDF::VERSION\n";
+   exit 0;
+}
 
 foreach my $flag (qw( skip ))
 {
-   foreach my $val (@{$opts{$flag."val"}})
+   foreach my $val (@{$opts{$flag.'val'}})
    {
-      foreach my $key (split /\D+/, $val)
+      foreach my $key (split /\D+/xms, $val)
       {
          $opts{$flag}->{$key} = 1;
       }
@@ -49,39 +61,44 @@ if (@ARGV < 2)
 my $infile = shift;
 my $outdir = shift;
 
-my $doc = CAM::PDF->new($infile);
-die "$CAM::PDF::errstr\n" if (!$doc);
+my $doc = CAM::PDF->new($infile) || die "$CAM::PDF::errstr\n";
 
 my $pages = $doc->numPages();
 my $nimages = 0;
 my $rimages = 0;
 my %doneobjs = ();
 
-for (my $p=1; $p <= $pages; $p++)
+for my $p (1..$pages)
 {
    my $c = $doc->getPageContent($p);
-   my @parts = split /(\/[\w]+\s*Do)\b/s, $c;
+   my @parts = split /(\/[\w]+\s*Do)\b/xms, $c;
    foreach my $part (@parts)
    {
-      if ($part =~ /^(\/[\w]+)\s*Do$/s)
+      if ($part =~ m/\A(\/[\w]+)\s*Do\z/xms)
       {
          my $ref = $1;
          my $xobj = $doc->dereference($ref, $p);
          my $objnum = $xobj->{objnum};
          my $im = $doc->getValue($xobj);
          my $w = $im->{Width} || $im->{W} || 0;
-         $w = $doc->getValue($w) if ($w);
+         if ($w)
+         {
+            $w = $doc->getValue($w);
+         }
          my $h = $im->{Height} || $im->{H} || 0;
-         $h = $doc->getValue($h) if ($h);
+         if ($h)
+         {
+            $h = $doc->getValue($h);
+         }
 
          next if (exists $doneobjs{$objnum});
 
          $nimages++;
-         print STDERR "Image $nimages page $p, $ref = object $objnum, (w,h)=($w,$h)\n" if ($opts{verbose});
+         _inform("Image $nimages page $p, $ref = object $objnum, (w,h)=($w,$h)", $opts{verbose});
 
          if (exists $opts{skip}->{$objnum})
          {
-            print STDERR "Skipping object $objnum\n" if ($opts{verbose});
+            _inform("Skipping object $objnum", $opts{verbose});
             next;
          }
 
@@ -89,14 +106,17 @@ for (my $p=1; $p <= $pages; $p++)
          if ($im->{Filter})
          {
             my $f = $im->{Filter};
-            if ($f->{type} eq "array")
+            if ($f->{type} eq 'array')
             {
                foreach my $e (@{$f->{value}})
                {
                   my $name = $doc->getValue($e);
-                  $name = $name->{value} if (ref $name);
+                  if (ref $name)
+                  {
+                     $name = $name->{value};
+                  }
                   #warn "Checking $name\n";
-                  if ($name eq "DCTDecode")
+                  if ($name eq 'DCTDecode')
                   {
                      $isjpg = 1;
                      last;
@@ -106,9 +126,12 @@ for (my $p=1; $p <= $pages; $p++)
             else
             {
                my $name = $doc->getValue($f);
-               $name = $name->{value} if (ref $name);
+               if (ref $name)
+               {
+                  $name = $name->{value};
+               }
                #warn "Checking $name\n";
-               if ($name eq "DCTDecode")
+               if ($name eq 'DCTDecode')
                {
                   $isjpg = 1;
                }
@@ -117,7 +140,7 @@ for (my $p=1; $p <= $pages; $p++)
 
          if (!$isjpg)
          {
-            print STDERR "Not a jpeg\n" if ($opts{verbose});
+            _inform('Not a jpeg', $opts{verbose});
          }
          else
          {
@@ -127,8 +150,7 @@ for (my $p=1; $p <= $pages; $p++)
                die "PDF error: Failed to get size of image\n";
             }
 
-            my $tmpl = CAM::PDF->new($opts{template});
-            die "$CAM::PDF::errstr\n" if (!$tmpl);
+            my $tmpl = CAM::PDF->new($opts{template}) || die "$CAM::PDF::errstr\n";
             
             # Get a handle on the needed data bits from the template
             my $media_array = $tmpl->getValue($tmpl->getPage(1)->{MediaBox});
@@ -137,8 +159,8 @@ for (my $p=1; $p <= $pages; $p++)
             $media_array->[2]->{value} = $w;
             $media_array->[3]->{value} = $h;
             my $page = $rawpage;
-            $page =~ s/xxx/$w/ig;
-            $page =~ s/yyy/$h/ig;
+            $page =~ s/xxx/$w/igxms;
+            $page =~ s/yyy/$h/igxms;
             $tmpl->setPageContent(1, $page);
             $tmpl->replaceObject(9, $doc, $objnum, 1);
 
@@ -147,9 +169,10 @@ for (my $p=1; $p <= $pages; $p++)
 
             if (!-d $outdir)
             {
-               `mkdir -p $outdir`;
+               require File::Path;
+               File::Path::mkpath($outdir);
             }
-            `convert -quality 50 -density 72x72 -page ${w}x$h pdf:$ofile jpg:$outdir/$objnum.jpg`;
+            `convert -quality 50 -density 72x72 -page ${w}x$h pdf:$ofile jpg:$outdir/$objnum.jpg`;  ## no critic
 
             $doneobjs{$objnum} = 1;
             $rimages++;
@@ -158,18 +181,32 @@ for (my $p=1; $p <= $pages; $p++)
    }
 }
 
-print STDERR "Extracted $rimages of $nimages images\n" if ($opts{verbose});
+_inform("Extracted $rimages of $nimages images", $opts{verbose});
+
+sub _inform
+{
+   my $str     = shift;
+   my $verbose = shift;
+
+   if ($verbose)
+   {
+      print STDERR $str, "\n";
+   }
+   return;
+}
 
 
 __END__
 
+=for stopwords extractjpgs.pl ImageMagick JPG
+
 =head1 NAME
 
 extractjpgs.pl - Save copies of all PDF JPG images to a directory
 
 =head1 SYNOPSIS
 
-extractjpgs.pl [options] infile.pdf outdirectory
+ extractjpgs.pl [options] infile.pdf outdirectory
 
  Options:
    -S --skip=imnum     don't output the specified images (can be used mutliple times)
@@ -178,28 +215,30 @@ extractjpgs.pl [options] infile.pdf outdirectory
    -V --version        print CAM::PDF version
 
 C<imnum> is a comma-separated list of integers indicating the images
-in order that they appear in the PDF.  Use listimages.pl to retrieve
+in order that they appear in the PDF.  Use F<listimages.pl> to retrieve
 the image numbers.
 
 =head1 DESCRIPTION
 
-Requires the ImageMagick C<convert> program to be available
+Requires the ImageMagick B<convert> program to be available
 
 Searches the PDF for JPG images and saves them as individual files in the
-specified directory.  The files are named <imnum>.jpg.
+specified directory.  The files are named C<E<lt>imnumE<gt>.jpg>.
 
 =head1 SEE ALSO
 
 CAM::PDF
 
-crunchjpgs.pl
+F<crunchjpgs.pl>
 
-listimages.pl
+F<listimages.pl>
 
-extractallimages.pl
+F<extractallimages.pl>
 
-uninlinepdfimages.pl
+F<uninlinepdfimages.pl>
 
 =head1 AUTHOR
 
 Clotho Advanced Media Inc., I<cpan@clotho.com>
+
+=cut
