@@ -1,10 +1,15 @@
 #!/usr/bin/perl -w
 
+package main;
+
+use warnings;
 use strict;
 use CAM::PDF;
 use Getopt::Long;
 use Pod::Usage;
 
+our $VERSION = '1.04_01';
+
 my %opts = (
             triggerclear => 0,
             verbose    => 0,
@@ -13,15 +18,22 @@ my %opts = (
             version    => 0,
             );
 
-Getopt::Long::Configure("bundling");
-GetOptions("t|triggerclear"  => \$opts{triggerclear},
-           "v|verbose"  => \$opts{verbose},
-           "o|order"    => \$opts{order},
-           "h|help"     => \$opts{help},
-           "V|version"  => \$opts{version},
+Getopt::Long::Configure('bundling');
+GetOptions('t|triggerclear'  => \$opts{triggerclear},
+           'v|verbose'  => \$opts{verbose},
+           'o|order'    => \$opts{order},
+           'h|help'     => \$opts{help},
+           'V|version'  => \$opts{version},
            ) or pod2usage(1);
-pod2usage(-exitstatus => 0, -verbose => 2) if ($opts{help});
-print("CAM::PDF v$CAM::PDF::VERSION\n"),exit(0) if ($opts{version});
+if ($opts{help})
+{
+   pod2usage(-exitstatus => 0, -verbose => 2);
+}
+if ($opts{version})
+{
+   print "CAM::PDF v$CAM::PDF::VERSION\n";
+   exit 0;
+}
 
 if (@ARGV < 3)
 {
@@ -31,21 +43,28 @@ if (@ARGV < 3)
 my $infile = shift;
 my $outfile = shift;
 
-my $doc = CAM::PDF->new($infile);
-die "$CAM::PDF::errstr\n" if (!$doc);
+my $doc = CAM::PDF->new($infile) || die "$CAM::PDF::errstr\n";
 
 my @list = (@ARGV);
 $doc->fillFormFields(@list);
 if ($opts{triggerclear})
 {
-   for (my $i=0; $i < @list; $i+=2)
+   # get even-numbered-index elemented (i.e. fieldnames)
+   my @names = map {$_ % 2 ? $list[$_] : ()} 0 .. $#list;
+   for my $name (@names)
    {
-      my $obj = $doc->getFormField($list[$i]);
-      delete $obj->{value}->{value}->{AA} if ($obj);
+      my $obj = $doc->getFormField($name);
+      if ($obj)
+      {
+         delete $obj->{value}->{value}->{AA};
+      }
    }
 }
 
-$doc->preserveOrder() if ($opts{order});
+if ($opts{order})
+{
+   $doc->preserveOrder();
+}
 if (!$doc->canModify())
 {
    die "This PDF forbids modification\n";
@@ -55,13 +74,15 @@ $doc->cleanoutput($outfile);
 
 __END__
 
+=for stopwords fillpdffields.pl
+
 =head1 NAME
 
 fillpdffields.pl - Replace PDF form fields with specified values
 
 =head1 SYNOPSIS
 
-fillpdffields.pl [options] infile.pdf outfile.pdf field value [field value ...]
+ fillpdffields.pl [options] infile.pdf outfile.pdf field value [field value ...]
 
  Options:
    -t --triggerclear   remove all of the form triggers after replacing values
@@ -73,15 +94,17 @@ fillpdffields.pl [options] infile.pdf outfile.pdf field value [field value ...]
 =head1 DESCRIPTION
 
 Fill in the forms in the PDF with the specified values, identified by
-their field names.  See listpdffields.pl for a the names of the form
+their field names.  See F<listpdffields.pl> for a the names of the form
 fields.
 
 =head1 SEE ALSO
 
 CAM::PDF
 
-listpdffields.pl
+F<listpdffields.pl>
 
 =head1 AUTHOR
 
 Clotho Advanced Media Inc., I<cpan@clotho.com>
+
+=cut
