@@ -1,23 +1,35 @@
 #!/usr/bin/perl -w
 
+package main;
+
+use warnings;
 use strict;
 use CAM::PDF;
 use Getopt::Long;
 use Pod::Usage;
 
+our $VERSION = '1.04_01';
+
 my %opts = (
             verbose    => 0,
             help       => 0,
             version    => 0,
             );
 
-Getopt::Long::Configure("bundling");
-GetOptions("v|verbose"  => \$opts{verbose},
-           "h|help"     => \$opts{help},
-           "V|version"  => \$opts{version},
+Getopt::Long::Configure('bundling');
+GetOptions('v|verbose'  => \$opts{verbose},
+           'h|help'     => \$opts{help},
+           'V|version'  => \$opts{version},
            ) or pod2usage(1);
-pod2usage(-exitstatus => 0, -verbose => 2) if ($opts{help});
-print("CAM::PDF v$CAM::PDF::VERSION\n"),exit(0) if ($opts{version});
+if ($opts{help})
+{
+   pod2usage(-exitstatus => 0, -verbose => 2);
+}
+if ($opts{version})
+{
+   print "CAM::PDF v$CAM::PDF::VERSION\n";
+   exit 0;
+}
 
 if (@ARGV < 1)
 {
@@ -26,18 +38,17 @@ if (@ARGV < 1)
 
 my $file = shift;
 
-my $doc = CAM::PDF->new($file);
-die "$CAM::PDF::errstr\n" if (!$doc);
+my $doc = CAM::PDF->new($file) || die "$CAM::PDF::errstr\n";
 
 my $pages = $doc->numPages();
 my $nimages = 0;
-for (my $p=1; $p <= $pages; $p++)
+for my $p (1..$pages)
 {
    my $c = $doc->getPageContent($p);
-   my @parts = split /(\/[\w]+\s*Do)\b/s, $c;
+   my @parts = split /(\/[\w]+\s*Do)\b/xms, $c;
    foreach my $part (@parts)
    {
-      if ($part =~ /^(\/[\w]+)\s*Do$/s)
+      if ($part =~ /\A(\/[\w]+)\s*Do\z/xms)
       {
          $nimages++;
          my $ref = $1;
@@ -45,11 +56,20 @@ for (my $p=1; $p <= $pages; $p++)
          my $objnum = $xobj->{objnum};
          my $im = $doc->getValue($xobj);
          my $l = $im->{Length} || $im->{L} || 0;
-         $l = $doc->getValue($l) if ($l);
+         if ($l)
+         {
+            $l = $doc->getValue($l);
+         }
          my $w = $im->{Width} || $im->{W} || 0;
-         $w = $doc->getValue($w) if ($w);
+         if ($w)
+         {
+            $w = $doc->getValue($w);
+         }
          my $h = $im->{Height} || $im->{H} || 0;
-         $h = $doc->getValue($h) if ($h);
+         if ($h)
+         {
+            $h = $doc->getValue($h);
+         }
          print "Image $nimages page $p, (w,h)=($w,$h), ref $ref = object $objnum, length $l\n";
       }
       else
@@ -58,28 +78,28 @@ for (my $p=1; $p <= $pages; $p++)
          # "ID" and "EI" in order in the page (which happened in the
          # PDF reference doc, of course!
 
-         while ($part =~ s/.*?\bBI\b\s*//s)
+         while ($part =~ s/.*?\bBI\b\s*//xms)
          {
-            if ($part =~ s/^(.*?)\s*\bEI\b\s*//s)
+            if ($part =~ s/\A(.*?)\s*\bEI\b\s*//xms)
             {
                my $im = $1;
-               $im =~ s/^.*\bBI\b//;  # this may get rid of a fake BI if there is one in the page
+               $im =~ s/\A.*\bBI\b//xms;  # this may get rid of a fake BI if there is one in the page
 
                # Easy tests:
-               next if ($im =~ /^\)/);
-               next if ($im =~ /\($/);
-               next if ($im !~ /\bID\b/);
+               next if ($im =~ m/ \A\) /xms);
+               next if ($im =~ m/ \(\z /xms);
+               next if ($im !~ m/ \bID\b /xms);
 
                # this is getting complex in the heuristics!
                # make sure that there is an open paren before every close
                # if not, then the "BI" was part of a string
                my $test = $im;
                my $failed = 0;
-               $test =~ s/\\[\(\)]//gs; # get rid of escaped parens for the test
-               while ($test =~ s/^(.*?)\)//s)
+               $test =~ s/ \\[\(\)] //gxms; # get rid of escaped parens for the test
+               while ($test =~ s/ \A(.*?)\) //xms)
                {
                   my $bit = $1;
-                  if ($bit !~ /\(/)
+                  if ($bit !~ m/ \( /xms)
                   {
                      $failed = 1;
                      last;
@@ -88,20 +108,20 @@ for (my $p=1; $p <= $pages; $p++)
                next if ($failed);
 
                # old test: count that the parens add up
-               #my @o = ($im =~ /(\()/g);
-               #my @os = ($im =~ /(\\\()/g);
-               #my @c = ($im =~ /(\))/g);
-               #my @cs = ($im =~ /(\\\))/g);
+               #my @o  = ($im =~ m/ (\()   /gxms);
+               #my @os = ($im =~ m/ (\\\() /gxms);
+               #my @c  = ($im =~ m/ (\))   /gxms);
+               #my @cs = ($im =~ m/ (\\\)) /gxms);
                #next if ((@o-@os) != (@c-@cs));
 
                $nimages++;
                my $w = 0;
                my $h = 0;
-               if ($im =~ /\/W(|idth)\s*(\d+)/)
+               if ($im =~ m/ \/W(|idth)\s*(\d+) /xms)
                {
                   $w = $2;
                }
-               if ($im =~ /\/H(|eight)\s*(\d+)/)
+               if ($im =~ m/ \/H(|eight)\s*(\d+) /xms)
                {
                   $h = $2;
                }
@@ -114,13 +134,15 @@ for (my $p=1; $p <= $pages; $p++)
 
 __END__
 
+=for stopwords listimages.pl
+
 =head1 NAME
 
 listimages.pl - Save copies of all PDF JPG images to a directory
 
 =head1 SYNOPSIS
 
-listimages.pl [options] infile.pdf
+ listimages.pl [options] infile.pdf
 
  Options:
    -v --verbose        print diagnostic messages
@@ -139,14 +161,16 @@ following formats:
 
 CAM::PDF
 
-crunchjpgs.pl
+F<crunchjpgs.pl>
 
-extractallimages.pl
+F<extractallimages.pl>
 
-extractjpgs.pl
+F<extractjpgs.pl>
 
-uninlinepdfimages.pl
+F<uninlinepdfimages.pl>
 
 =head1 AUTHOR
 
 Clotho Advanced Media Inc., I<cpan@clotho.com>
+
+=cut
