@@ -1,33 +1,46 @@
 #!/usr/bin/perl -w
 
+package main;
+
+use warnings;
 use strict;
 use CAM::PDF;
 use Getopt::Long;
 use Pod::Usage;
+use English qw(-no_match_vars);
+
+our $VERSION = '1.04_01';
 
 my %opts = (
             density    => undef,
             xdensity    => undef,
             ydensity    => undef,
             check      => 0,
-            renderer   => "CAM::PDF::Renderer::Dump",
+            renderer   => 'CAM::PDF::Renderer::Dump',
             verbose    => 0,
             help       => 0,
             version    => 0,
             );
 
-Getopt::Long::Configure("bundling");
-GetOptions("r|renderer=s" => \$opts{renderer},
-           "d|density=f"  => \$opts{density},
-           "x|xdensity=f" => \$opts{xdensity},
-           "y|ydensity=f" => \$opts{ydensity},
-           "c|check"      => \$opts{check},
-           "v|verbose"    => \$opts{verbose},
-           "h|help"       => \$opts{help},
-           "V|version"    => \$opts{version},
+Getopt::Long::Configure('bundling');
+GetOptions('r|renderer=s' => \$opts{renderer},
+           'd|density=f'  => \$opts{density},
+           'x|xdensity=f' => \$opts{xdensity},
+           'y|ydensity=f' => \$opts{ydensity},
+           'c|check'      => \$opts{check},
+           'v|verbose'    => \$opts{verbose},
+           'h|help'       => \$opts{help},
+           'V|version'    => \$opts{version},
            ) or pod2usage(1);
-pod2usage(-exitstatus => 0, -verbose => 2) if ($opts{help});
-print("CAM::PDF v$CAM::PDF::VERSION\n"),exit(0) if ($opts{version});
+if ($opts{help})
+{
+   pod2usage(-exitstatus => 0, -verbose => 2);
+}
+if ($opts{version})
+{
+   print "CAM::PDF v$CAM::PDF::VERSION\n";
+   exit 0;
+}
 
 if (defined $opts{density})
 {
@@ -35,11 +48,23 @@ if (defined $opts{density})
 }
 if (defined $opts{xdensity} || defined $opts{ydensity})
 {
-   eval "require $opts{renderer}";
-   die $@ if ($@);
-   no strict 'refs';
-   ${$opts{renderer}."::xdensity"} = $opts{xdensity} if (defined $opts{xdensity});
-   ${$opts{renderer}."::ydensity"} = $opts{ydensity} if (defined $opts{ydensity});
+   eval "require $opts{renderer}";  ## no critic for string eval
+   if ($EVAL_ERROR)
+   {
+      die $EVAL_ERROR;
+   }
+   if (defined $opts{xdensity})
+   {
+      no strict 'refs';
+      my $varname = $opts{renderer}.'::xdensity';
+      $$varname = $opts{xdensity};
+   }
+   if (defined $opts{ydensity})
+   {
+      no strict 'refs';
+      my $varname = $opts{renderer}.'::ydensity';
+      $$varname = $opts{ydensity};
+   }
 }
 
 if (@ARGV < 1)
@@ -50,16 +75,15 @@ if (@ARGV < 1)
 my $file = shift;
 my $pagelist = shift;
 
-my $doc = CAM::PDF->new($file);
-die "$CAM::PDF::errstr\n" if (!$doc);
+my $doc = CAM::PDF->new($file) || die "$CAM::PDF::errstr\n";
 
-foreach my $p ($doc->rangeToArray(1,$doc->numPages(),$pagelist))
+foreach my $p ($doc->rangeToArray(1, $doc->numPages(), $pagelist))
 {
    my $tree = $doc->getPageContentTree($p, $opts{verbose});
    if ($opts{check})
    {
       print "Checking page $p\n";
-      unless ($tree->validate())
+      if (!$tree->validate())
       {
          print "  Failed\n";
       }
@@ -70,13 +94,15 @@ foreach my $p ($doc->rangeToArray(1,$doc->numPages(),$pagelist))
 
 __END__
 
+=for stopwords renderpdf.pl renderers
+
 =head1 NAME
 
 renderpdf.pl - Applies a renderer to one or more PDF pages
 
 =head1 SYNOPSIS
 
-renderpdf.pl [options] infile.pdf [<pagenums>]
+ renderpdf.pl [options] infile.pdf [<pagenums>]
 
  Options:
    -r --renderer=class uses this renderer class (default: CAM::PDF::Renderer::Dump)
@@ -104,8 +130,10 @@ CAM::PDF::Renderer::Text and the like).
 
 CAM::PDF
 
-getpdftext.pl
+F<getpdftext.pl>
 
 =head1 AUTHOR
 
 Clotho Advanced Media Inc., I<cpan@clotho.com>
+
+=cut
