@@ -1,11 +1,15 @@
 #!/usr/bin/perl -w
 
+package main;
+
 use warnings;
 use strict;
 use CAM::PDF;
 use Getopt::Long;
 use Pod::Usage;
 
+our $VERSION = '1.04_01';
+
 my %opts = (
             verbose    => 0,
             order      => 0,
@@ -68,13 +72,15 @@ $doc->cleanoutput($outfile);
 
 __END__
 
+=for stopwords setpdfpage.pl
+
 =head1 NAME
 
 setpdfpage.pl - Replace a page of PDF layout
 
 =head1 SYNOPSIS
 
-setpdfpage.pl [options] infile.pdf page.txt pagenum [outfile.pdf]
+ setpdfpage.pl [options] infile.pdf page.txt pagenum [outfile.pdf]
 
  Options:
    -o --order          preserve the internal PDF ordering for output
@@ -91,8 +97,10 @@ page indicated.  The existing page layout is discarded.
 
 CAM::PDF
 
-getpdfpage.pl
+F<getpdfpage.pl>
 
 =head1 AUTHOR
 
 Clotho Advanced Media Inc., I<cpan@clotho.com>
+
+=cut
